# Release History

## 0.2.0 (2022-02-09)

- Fixed some REST api bugs

## 0.2.0-rc1 (2022-02-03)

- Added support for a Capricorn version of FetchD network

## 0.1.4 (2021-08-25)

- Dependencies refactored and some dependencies will install only with --dev parameter

## 0.1.3 (2021-08-24)

- Lowered required version of grpcio to 1.32.0 or greater

## 0.1.2 (2021-08-23)

- First public release
